@@ -47,6 +47,21 @@ class ClassTest(unittest.TestCase):
     def test_str(self):
         assert 'ORapi' in str(self.testobj)
 
+    def test_session_property(self):
+        # The session property is defined in the base class but we
+        # will unit test it here anyway, to make sure nobody changes
+        # the base class in a way that breaks us.
+        aw = self.testobj
+        original_session = aw.session
+        assert original_session
+        # test the setter and getter
+        fake_session = MagicMock()
+        aw.session = fake_session
+        assert aw.session is fake_session
+        # put the real one back
+        aw.session = original_session
+        assert aw.session is original_session
+
     def test_get(self):
         hdrs = {'fake-header': 'fake-value'}
         expected = 'unit test get result'
